﻿using System.ComponentModel;
using System.Windows.Forms;
using Infragistics.Win.UltraWinTree;

namespace BindingTreeSample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            this.InitializeComponent();
            var root = new NodeItem("root");

            root.Children.Add(new NodeItem("child 1"));
            root.Children.Add(new NodeItem("child 2"));

            // if this node is hidden, the child 2.1.1 -> 2.1.3 nodes will not be visible
            root.Children[0].Children.Add(new NodeItem("hide me and child 2.1.1 -> child 2.1.3 will be invisible"));

            root.Children[1].Children.Add(new NodeItem("child 2.1"));
            root.Children[1].Children.Add(new NodeItem("child 2.2"));
            root.Children[1].Children.Add(new NodeItem("child 2.3"));
            root.Children[1].Children[0].Children.Add(new NodeItem("child 2.1.1"));
            root.Children[1].Children[1].Children.Add(new NodeItem("child 2.1.2"));
            root.Children[1].Children[2].Children.Add(new NodeItem("child 2.1.3"));

            var collection = new BindingList<NodeItem> {root};


            this.ultraTree1.DataSource = collection;

            this.ultraTree1.ExpandAll();
        }

        private void ultraTree1_ColumnSetGenerated(object sender, ColumnSetGeneratedEventArgs e)
        {
            e.ColumnSet.NodeTextColumn = e.ColumnSet.Columns["Text"];
        }

        #region Nested type: DummyItem

        public class DummyItem : NodeItemBase
        {
        }

        #endregion

        #region Nested type: NodeItem

        public class NodeItem : NodeItemBase
        {
            public NodeItem(string text)
                : base(text)
            {
            }
        }

        #endregion

        #region Nested type: NodeItemBase

        public abstract class NodeItemBase
        {
            protected NodeItemBase()
            {
                this.Children = new BindingList<NodeItemBase>();
            }

            protected NodeItemBase(string text)
                : this()
            {
                this.Text = text;
            }

            public string Text { get; set; }
            public BindingList<NodeItemBase> Children { get; private set; }
        }

        #endregion
    }
}